@@ -7,6 +7,7 @@ from flask import current_app
 import click
 import apispec
 from apispec.ext.marshmallow import MarshmallowPlugin
+from webargs.fields import DelimitedList
 
 try:  # pragma: no cover
     import yaml
@@ -28,6 +29,18 @@ def _add_leading_slash(string):
     return string if string.startswith("/") else "/" + string
 
 
+def delimited_list2param(self, field, **kwargs):
+    """apispec parameter attribute function documenting DelimitedList field"""
+    ret = {}
+    if isinstance(field, DelimitedList):
+        if self.openapi_version.major < 3:
+            ret["collectionFormat"] = "csv"
+        else:
+            ret["explode"] = False
+            ret["style"] = "form"
+    return ret
+
+
 class DocBlueprintMixin:
     """Extend Api to serve the spec in a dedicated blueprint."""
 
@@ -217,6 +230,8 @@ class APISpecMixin(DocBlueprintMixin):
             self._register_converter(*args)
         # Register Upload field properties function
         self.ma_plugin.converter.add_attribute_function(uploadfield2properties)
+        # Register DelimitedList field parameter attribute function
+        self.ma_plugin.converter.add_parameter_attribute_function(delimited_list2param)
 
         # Lazy register default responses
         self._register_responses()
@@ -305,7 +320,7 @@ class APISpecMixin(DocBlueprintMixin):
             self._register_field(field, *args)
 
     def _register_field(self, field, *args):
-        self.ma_plugin.map_to_openapi_type(*args)(field)
+        self.ma_plugin.map_to_openapi_type(field, *args)
 
     def _register_responses(self):
         """Lazyly register default responses for all status codes"""
