@@ -50,12 +50,12 @@ class CounterSchema(ma.Schema):
         cls.dump_count = 0
 
     @ma.post_load(pass_many=True)
-    def increment_load_count(self, data, many, **kwargs):
+    def increment_load_count(self, data, **kwargs):
         self.__class__.load_count += 1
         return data
 
     @ma.post_dump(pass_many=True)
-    def increment_dump_count(self, data, many, **kwargs):
+    def increment_dump_count(self, data, **kwargs):
         self.__class__.dump_count += 1
         return data
 
@@ -66,9 +66,6 @@ def schemas():
         item_id = ma.fields.Int(dump_only=True)
         field = ma.fields.Int(attribute="db_field")
 
-    class DocEtagSchema(CounterSchema):
-        field = ma.fields.Int(attribute="db_field")
-
     class QueryArgsSchema(ma.Schema):
         class Meta:
             ordered = True
@@ -81,6 +78,6 @@ def schemas():
         error_id = ma.fields.Str()
         text = ma.fields.Str()
 
-    return namedtuple(
-        "Model", ("DocSchema", "DocEtagSchema", "QueryArgsSchema", "ClientErrorSchema")
-    )(DocSchema, DocEtagSchema, QueryArgsSchema, ClientErrorSchema)
+    return namedtuple("Model", ("DocSchema", "QueryArgsSchema", "ClientErrorSchema"))(
+        DocSchema, QueryArgsSchema, ClientErrorSchema
+    )
