@@ -27,20 +27,20 @@ def implicit_data_and_schema_etag_blueprint(collection, schemas):
     blp = Blueprint("test", __name__, url_prefix="/test")
 
     @blp.route("/")
+    @blp.etag
     class Resource(MethodView):
-        @blp.etag
         @blp.response(200, DocSchema(many=True))
         @blp.paginate(Page)
         def get(self):
             return collection.items
 
-        @blp.etag
         @blp.arguments(DocSchema)
         @blp.response(201, DocSchema)
         def post(self, new_item):
             return collection.post(new_item)
 
     @blp.route("/<int:item_id>")
+    @blp.etag
     class ResourceById(MethodView):
         def _get_item(self, item_id):
             try:
@@ -48,12 +48,10 @@ def implicit_data_and_schema_etag_blueprint(collection, schemas):
             except ItemNotFound:
                 abort(404)
 
-        @blp.etag
         @blp.response(200, DocSchema)
         def get(self, item_id):
             return self._get_item(item_id)
 
-        @blp.etag
         @blp.arguments(DocSchema)
         @blp.response(200, DocSchema)
         def put(self, new_item, item_id):
@@ -62,7 +60,6 @@ def implicit_data_and_schema_etag_blueprint(collection, schemas):
             blp.check_etag(item, DocSchema)
             return collection.put(item_id, new_item)
 
-        @blp.etag
         @blp.response(204)
         def delete(self, item_id):
             item = self._get_item(item_id)
@@ -73,69 +70,6 @@ def implicit_data_and_schema_etag_blueprint(collection, schemas):
     return blp
 
 
-def implicit_data_explicit_schema_etag_blueprint(collection, schemas):
-    """Blueprint with implicit ETag computation, explicit schema
-
-    ETag computed automatically with specific ETag schema
-    """
-
-    DocSchema = schemas.DocSchema
-    DocEtagSchema = schemas.DocEtagSchema
-
-    blp = Blueprint("test", __name__, url_prefix="/test")
-
-    @blp.route("/")
-    class Resource(MethodView):
-        @blp.etag(DocEtagSchema(many=True))
-        @blp.response(200, DocSchema(many=True))
-        @blp.paginate()
-        def get(self, pagination_parameters):
-            pagination_parameters.item_count = len(collection.items)
-            return collection.items[
-                pagination_parameters.first_item : pagination_parameters.last_item + 1
-            ]
-
-        @blp.etag(DocEtagSchema)
-        @blp.arguments(DocSchema)
-        @blp.response(201, DocSchema)
-        def post(self, new_item):
-            return collection.post(new_item)
-
-    @blp.route("/<int:item_id>")
-    class ResourceById(MethodView):
-        def _get_item(self, item_id):
-            try:
-                return collection.get_by_id(item_id)
-            except ItemNotFound:
-                abort(404)
-
-        @blp.etag(DocEtagSchema)
-        @blp.response(200, DocSchema)
-        def get(self, item_id):
-            item = self._get_item(item_id)
-            return item
-
-        @blp.etag(DocEtagSchema)
-        @blp.arguments(DocSchema)
-        @blp.response(200, DocSchema)
-        def put(self, new_item, item_id):
-            item = self._get_item(item_id)
-            # Check ETag is a manual action, ETag schema is used
-            blp.check_etag(item)
-            new_item = collection.put(item_id, new_item)
-            return new_item
-
-        @blp.etag(DocEtagSchema)
-        @blp.response(204)
-        def delete(self, item_id):
-            item = self._get_item(item_id)
-            # Check ETag is a manual action, ETag schema is used
-            blp.check_etag(item)
-            collection.delete(item_id)
-
-    return blp
-
-
 def explicit_data_no_schema_etag_blueprint(collection, schemas):
     """Blueprint with explicit ETag computation, no schema
 
@@ -149,8 +83,8 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
     blp = Blueprint("test", __name__, url_prefix="/test")
 
     @blp.route("/")
+    @blp.etag
     class Resource(MethodView):
-        @blp.etag
         @blp.response(200, DocSchema(many=True))
         @blp.paginate()
         def get(self, pagination_parameters):
@@ -161,7 +95,6 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
                 pagination_parameters.first_item : pagination_parameters.last_item + 1
             ]
 
-        @blp.etag
         @blp.arguments(DocSchema)
         @blp.response(201, DocSchema)
         def post(self, new_item):
@@ -170,6 +103,7 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
             return collection.post(new_item)
 
     @blp.route("/<int:item_id>")
+    @blp.etag
     class ResourceById(MethodView):
         def _get_item(self, item_id):
             try:
@@ -177,7 +111,6 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
             except ItemNotFound:
                 abort(404)
 
-        @blp.etag
         @blp.response(200, DocSchema)
         def get(self, item_id):
             item = self._get_item(item_id)
@@ -185,7 +118,6 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
             blp.set_etag(item["db_field"])
             return item
 
-        @blp.etag
         @blp.arguments(DocSchema)
         @blp.response(200, DocSchema)
         def put(self, new_item, item_id):
@@ -197,7 +129,6 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
             blp.set_etag(new_item["db_field"])
             return new_item
 
-        @blp.etag
         @blp.response(204)
         def delete(self, item_id):
             item = self._get_item(item_id)
@@ -210,20 +141,20 @@ def explicit_data_no_schema_etag_blueprint(collection, schemas):
 
 @pytest.fixture(
     params=[
-        (implicit_data_and_schema_etag_blueprint, "Schema"),
-        (implicit_data_explicit_schema_etag_blueprint, "ETag schema"),
-        (explicit_data_no_schema_etag_blueprint, "No schema"),
+        (implicit_data_and_schema_etag_blueprint, True),
+        (explicit_data_no_schema_etag_blueprint, False),
     ]
 )
 def blueprint_fixture(request, collection, schemas):
     blp_factory = request.param[0]
-    return blp_factory(collection, schemas), request.param[1]
+    etag_schema = request.param[1]
+    return blp_factory(collection, schemas), etag_schema
 
 
 class TestFullExample:
     def test_examples(self, app, blueprint_fixture, schemas):
 
-        blueprint, bp_schema = blueprint_fixture
+        blueprint, etag_schema = blueprint_fixture
 
         api = Api(app)
         api.register_blueprint(blueprint)
@@ -231,22 +162,16 @@ class TestFullExample:
         client = app.test_client()
 
         @contextmanager
-        def assert_counters(
-            schema_load, schema_dump, etag_schema_load, etag_schema_dump
-        ):
-            """Check number of calls to dump/load methods of schemas"""
+        def assert_counters(schema_load, schema_dump):
+            """Check number of calls to dump/load methods of schema"""
             schemas.DocSchema.reset_load_count()
             schemas.DocSchema.reset_dump_count()
-            schemas.DocEtagSchema.reset_load_count()
-            schemas.DocEtagSchema.reset_dump_count()
             yield
             assert schemas.DocSchema.load_count == schema_load
             assert schemas.DocSchema.dump_count == schema_dump
-            assert schemas.DocEtagSchema.load_count == etag_schema_load
-            assert schemas.DocEtagSchema.dump_count == etag_schema_dump
 
         # GET collection without ETag: OK
-        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+        with assert_counters(0, 1):
             response = client.get("/test/")
             assert response.status_code == 200
             list_etag = response.headers["ETag"]
@@ -257,13 +182,13 @@ class TestFullExample:
             }
 
         # GET collection with correct ETag: Not modified
-        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+        with assert_counters(0, 1):
             response = client.get("/test/", headers={"If-None-Match": list_etag})
         assert response.status_code == 304
 
         # POST item_1
         item_1_data = {"field": 0}
-        with assert_counters(1, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+        with assert_counters(1, 1):
             response = client.post(
                 "/test/", data=json.dumps(item_1_data), content_type="application/json"
             )
@@ -271,7 +196,7 @@ class TestFullExample:
         item_1_id = response.json["item_id"]
 
         # GET collection with wrong/outdated ETag: OK
-        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+        with assert_counters(0, 1):
             response = client.get("/test/", headers={"If-None-Match": list_etag})
         assert response.status_code == 200
         list_etag = response.headers["ETag"]
@@ -286,18 +211,13 @@ class TestFullExample:
         }
 
         # GET by ID without ETag: OK
-        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+        with assert_counters(0, 1):
             response = client.get(f"/test/{item_1_id}")
         assert response.status_code == 200
         item_etag = response.headers["ETag"]
 
         # GET by ID with correct ETag: Not modified
-        with assert_counters(
-            0,
-            0 if bp_schema == "No schema" else 1,
-            0,
-            1 if bp_schema == "ETag schema" else 0,
-        ):
+        with assert_counters(0, 1 if etag_schema else 0):
             response = client.get(
                 f"/test/{item_1_id}", headers={"If-None-Match": item_etag}
             )
@@ -305,7 +225,7 @@ class TestFullExample:
 
         # PUT without ETag: Precondition required error
         item_1_data["field"] = 1
-        with assert_counters(0, 0, 0, 0):
+        with assert_counters(0, 0):
             response = client.put(
                 f"/test/{item_1_id}",
                 data=json.dumps(item_1_data),
@@ -314,12 +234,7 @@ class TestFullExample:
         assert response.status_code == 428
 
         # PUT with correct ETag: OK
-        with assert_counters(
-            1,
-            2 if bp_schema == "Schema" else 1,
-            0,
-            2 if bp_schema == "ETag schema" else 0,
-        ):
+        with assert_counters(1, 2 if etag_schema else 1):
             response = client.put(
                 f"/test/{item_1_id}",
                 data=json.dumps(item_1_data),
@@ -331,12 +246,7 @@ class TestFullExample:
 
         # PUT with wrong/outdated ETag: Precondition failed error
         item_1_data["field"] = 2
-        with assert_counters(
-            1,
-            1 if bp_schema == "Schema" else 0,
-            0,
-            1 if bp_schema == "ETag schema" else 0,
-        ):
+        with assert_counters(1, 1 if etag_schema else 0):
             response = client.put(
                 f"/test/{item_1_id}",
                 data=json.dumps(item_1_data),
@@ -346,14 +256,14 @@ class TestFullExample:
         assert response.status_code == 412
 
         # GET by ID with wrong/outdated ETag: OK
-        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+        with assert_counters(0, 1):
             response = client.get(
                 f"/test/{item_1_id}", headers={"If-None-Match": item_etag}
             )
         assert response.status_code == 200
 
         # GET collection with pagination set to 1 element per page
-        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+        with assert_counters(0, 1):
             response = client.get(
                 "/test/",
                 headers={"If-None-Match": list_etag},
@@ -373,7 +283,7 @@ class TestFullExample:
 
         # POST item_2
         item_2_data = {"field": 1}
-        with assert_counters(1, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+        with assert_counters(1, 1):
             response = client.post(
                 "/test/", data=json.dumps(item_2_data), content_type="application/json"
             )
@@ -382,7 +292,7 @@ class TestFullExample:
         # GET collection with pagination set to 1 element per page
         # Content is the same (item_1) but pagination metadata has changed
         # so we don't get a 304 and the data is returned again
-        with assert_counters(0, 1, 0, 1 if bp_schema == "ETag schema" else 0):
+        with assert_counters(0, 1):
             response = client.get(
                 "/test/",
                 headers={"If-None-Match": list_etag},
@@ -402,29 +312,19 @@ class TestFullExample:
         }
 
         # DELETE without ETag: Precondition required error
-        with assert_counters(0, 0, 0, 0):
+        with assert_counters(0, 0):
             response = client.delete(f"/test/{item_1_id}")
         assert response.status_code == 428
 
         # DELETE with wrong/outdated ETag: Precondition failed error
-        with assert_counters(
-            0,
-            1 if bp_schema == "Schema" else 0,
-            0,
-            1 if bp_schema == "ETag schema" else 0,
-        ):
+        with assert_counters(0, 1 if etag_schema else 0):
             response = client.delete(
                 f"/test/{item_1_id}", headers={"If-Match": item_etag}
             )
         assert response.status_code == 412
 
         # DELETE with correct ETag: No Content
-        with assert_counters(
-            0,
-            1 if bp_schema == "Schema" else 0,
-            0,
-            1 if bp_schema == "ETag schema" else 0,
-        ):
+        with assert_counters(0, 1 if etag_schema else 0):
             response = client.delete(
                 f"/test/{item_1_id}", headers={"If-Match": new_item_etag}
             )
